-- Bug 39295 - Workstaton crash, Hitting Cancel, Bad Print setup , corrupts the data for the revenue recognition process.

-- As a result of this bug, the database will have project transaction and GL batch transaction generated, but the GL batch header is missing.
-- With no batch record, the GL transaction cannot be posted. Therefore the project revenue and recorded GL revenue will not be in sync.
-- Ultimately a GL posting is required to correct this.

-- This SQL script will attempt to correct the orphaned GLTran records by generating a 'H'old status Batch record for the orphaned GL transactions.
-- This will allow the user to turn on 'Initialize Mode' and pull the batch up in General Ledger Journal Transaction (01.010.00) for examination.
-- The batch can then be released for posting or it can be deleted.

INSERT INTO Batch
          (Acct, AutoRev, AutoRevCopy, BalanceType, BankAcct, BankSub, BaseCuryID, BatNbr, BatType,
           clearamt, Cleared, CpnyID, Crtd_DateTime, Crtd_Prog, Crtd_User, CrTot, CtrlTot,
           CuryCrTot, CuryCtrlTot, CuryDepositAmt, CuryDrTot, CuryEffDate, CuryId, CuryMultDiv, CuryRate, CuryRateType,
           Cycle, DateClr, DateEnt, DepositAmt, Descr, DrTot, EditScrnNbr, GLPostOpt, JrnlType, LedgerID,
           LUpd_DateTime, LUpd_Prog, LUpd_User, Module, NbrCycle, NoteID, OrigBatNbr, OrigCpnyID, OrigScrnNbr, PerEnt, PerPost, Rlsed,
           S4Future01, S4Future02, S4Future03, S4Future04, S4Future05, S4Future06, S4Future07, S4Future08, S4Future09, S4Future10, S4Future11, S4Future12,
           [Status], Sub, User1, User2, User3, User4, User5, User6, User7, User8, VOBatNbrForPP)
    SELECT SPACE(0), 0, 0, 'A', SPACE(0), SPACE(0), BaseCuryID, BatNbr, 'N',
           0.0, 0, CpnyID, GETDATE(), 'SSMS', 'SQL', Sum_CrAmt, Sum_DrAmt,
           Sum_CrAmt, Sum_DrAmt, 0.0, Sum_DrAmt, '1/1/1900', BaseCuryID, 'M', 1.0, SPACE(0),
           0, '1/1/1900', '1/1/1900', 0, 'Bug39295', Sum_DrAmt, 'PAREV', 'D', JrnlType, LedgerID,
           GETDATE(), 'SSMS', 'SQL', 'PA', 0, 0, SPACE(0), SPACE(0), SPACE(0), PerEnt, PerPost, 1,
           SPACE(0), SPACE(0), 0.0, 0.0, 0.0, 0.0, '1/1/1900', '1/1/1900', 0, 0, SPACE(0), SPACE(0),
           'H', SPACE(0), SPACE(0), SPACE(0), 0.0, 0.0, SPACE(0), SPACE(0), '1/1/1900', '1/1/1900', SPACE(0)
    FROM (SELECT CpnyID, BaseCuryID, Module, JrnlType, LedgerID, BatNbr, PerEnt, PerPost, SUM(CrAmt) AS Sum_CrAmt, SUM(DrAmt) AS Sum_DrAmt
          FROM GLTran
          WHERE Module = 'PA'
            AND NOT EXISTS (SELECT *
                            FROM batch
                            WHERE Module = 'PA'
                              AND BatNbr = GLTran.BatNbr)
            AND Crtd_Prog = 'PAREV'
            AND JrnlType = 'REV'
          GROUP BY CpnyID, BaseCuryID, Module, JrnlType, LedgerID, BatNbr, PerEnt, PerPost) AS NewBatch

-- Output a list of GL batches related to this bug
SELECT Module,
       BatNbr AS [GL Batch Number],
       SUBSTRING(PerEnt, 5, 2) + '-' + SUBSTRING(PerEnt, 1, 4) AS [Period Entered],
	   SUBSTRING(PerEnt, 5, 2) + '-' + SUBSTRING(PerPost, 1, 4) AS [Period To Post],
	   CtrlTot AS [Control Total]
FROM Batch
WHERE Descr = 'Bug39295'
  AND [Status] = 'H'
ORDER BY BatNbr